FabricToolbarStyle class
Visual style for the built-in toolbar.
Constructors
- FabricToolbarStyle({Color? backgroundColor, Color? selectedColor, Color? iconColor, Color? selectedIconColor, double borderRadius = 12.0, double elevation = 4.0, double iconSize = 22.0, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 8, vertical: 6)})
-
const
Properties
- backgroundColor → Color?
-
Toolbar background. Defaults to ColorScheme.surface.
final
- borderRadius → double
-
final
- elevation → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → Color?
-
Icon color. Defaults to ColorScheme.onSurface.
final
- iconSize → double
-
final
- padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color?
-
Highlight for the active mode tool. Defaults to ColorScheme.primaryContainer.
final
- selectedIconColor → Color?
-
Icon color when active. Defaults to ColorScheme.onPrimaryContainer.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited